"""Mix-in for robots that process multiple URLs in parallel.

This file is a part of Bookmarks database and Internet robot.

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2024 PhiloSoft Design"
__license__ = "GNU GPL"

__all__ = ['multi_mixin']


class multi_mixin:
    max_urls = 10  # Small default
    report_checked = False

    def __init__(self, *args, **kw):
        if isinstance(self.max_urls, str):
            self.max_urls = int(self.max_urls)

        # Bookmarks waiting to be processed;
        # maps {URL: [bookmark, saved parent, task]}
        self.bookmarks = {}
        self.pending = set()  # pending tasks

    def check_bookmark(self, bookmark):
        href = bookmark.href
        bookmarks = self.bookmarks
        if href in bookmarks:
            return
        bookmarks[href] = [bookmark, None, None]
        if len(bookmarks) < self.max_urls:
            return
        self.wait()

    def stop(self):
        while self.bookmarks or self.pending:
            self.wait()
