"""Thin wrapper for module Robots. Provides "default" robot

This file is a part of Bookmarks database and Internet robot.

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 1997-2024 PhiloSoft Design"
__license__ = "GNU GPL"

__all__ = ['import_robot', 'robot']


from os import environ
from bkmk_objects import parse_params, set_params

robot_names, robot_params = parse_params(
    environ.get("BKMK_ROBOT", "multirequests,aio"))


def import_robot(robot_name):
    ns = locals()
    exec("from Robots import bkmk_r%s" % robot_name, globals(), ns)
    exec("robot = bkmk_r%s.robot_%s" % (robot_name, robot_name), globals(), ns)
    return ns['robot']


for robot_name in robot_names.split(','):
    try:
        robot = import_robot(robot_name)
    except ImportError:
        pass
    else:
        set_params(robot, robot_params)
        break
else:
    raise ValueError("No robot found, tried " + robot_names)
